# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/notebook/v1/notebook.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAgithub.com/metaprov/modelaapi/services/notebook/v1/notebook.proto\x12\x32github.com.metaprov.modelaapi.services.notebook.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1aHgithub.com/metaprov/modelaapi/pkg/apis/training/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\"\xf7\x01\n\x14ListNotebooksRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x64\n\x06labels\x18\x02 \x03(\x0b\x32T.github.com.metaprov.modelaapi.services.notebook.v1.ListNotebooksRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8b\x01\n\x15ListNotebooksResponse\x12Y\n\tnotebooks\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NotebookList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x12\n\x10NotebookResponse\"m\n\x15\x43reateNotebookRequest\x12T\n\x08notebook\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Notebook\"\x18\n\x16\x43reateNotebookResponse\"\x9d\x01\n\x15UpdateNotebookRequest\x12T\n\x08notebook\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Notebook\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x18\n\x16UpdateNotebookResponse\"5\n\x12GetNotebookRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"y\n\x13GetNotebookResponse\x12T\n\x08notebook\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Notebook\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"8\n\x15\x44\x65leteNotebookRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x18\n\x16\x44\x65leteNotebookResponse2\xad\x08\n\x0fNotebookService\x12\xbb\x01\n\rListNotebooks\x12H.github.com.metaprov.modelaapi.services.notebook.v1.ListNotebooksRequest\x1aI.github.com.metaprov.modelaapi.services.notebook.v1.ListNotebooksResponse\"\x15\x82\xd3\xe4\x93\x02\x0f\x12\r/v1/notebooks\x12\xc1\x01\n\x0e\x43reateNotebook\x12I.github.com.metaprov.modelaapi.services.notebook.v1.CreateNotebookRequest\x1aJ.github.com.metaprov.modelaapi.services.notebook.v1.CreateNotebookResponse\"\x18\x82\xd3\xe4\x93\x02\x12\"\r/v1/notebooks:\x01*\x12\xc8\x01\n\x0bGetNotebook\x12\x46.github.com.metaprov.modelaapi.services.notebook.v1.GetNotebookRequest\x1aG.github.com.metaprov.modelaapi.services.notebook.v1.GetNotebookResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /v1/notebooks/{namespace}/{name}\x12\xf8\x01\n\x0eUpdateNotebook\x12I.github.com.metaprov.modelaapi.services.notebook.v1.UpdateNotebookRequest\x1aJ.github.com.metaprov.modelaapi.services.notebook.v1.UpdateNotebookResponse\"O\x82\xd3\xe4\x93\x02I\x1a\x44/v1/notebooks/{notebook.metadata.namespace}/{notebook.metadata.name}:\x01*\x12\xd1\x01\n\x0e\x44\x65leteNotebook\x12I.github.com.metaprov.modelaapi.services.notebook.v1.DeleteNotebookRequest\x1aJ.github.com.metaprov.modelaapi.services.notebook.v1.DeleteNotebookResponse\"(\x82\xd3\xe4\x93\x02\"* /v1/notebooks/{namespace}/{name}B4Z2github.com/metaprov/modelaapi/services/notebook/v1b\x06proto3')



_LISTNOTEBOOKSREQUEST = DESCRIPTOR.message_types_by_name['ListNotebooksRequest']
_LISTNOTEBOOKSREQUEST_LABELSENTRY = _LISTNOTEBOOKSREQUEST.nested_types_by_name['LabelsEntry']
_LISTNOTEBOOKSRESPONSE = DESCRIPTOR.message_types_by_name['ListNotebooksResponse']
_NOTEBOOKRESPONSE = DESCRIPTOR.message_types_by_name['NotebookResponse']
_CREATENOTEBOOKREQUEST = DESCRIPTOR.message_types_by_name['CreateNotebookRequest']
_CREATENOTEBOOKRESPONSE = DESCRIPTOR.message_types_by_name['CreateNotebookResponse']
_UPDATENOTEBOOKREQUEST = DESCRIPTOR.message_types_by_name['UpdateNotebookRequest']
_UPDATENOTEBOOKRESPONSE = DESCRIPTOR.message_types_by_name['UpdateNotebookResponse']
_GETNOTEBOOKREQUEST = DESCRIPTOR.message_types_by_name['GetNotebookRequest']
_GETNOTEBOOKRESPONSE = DESCRIPTOR.message_types_by_name['GetNotebookResponse']
_DELETENOTEBOOKREQUEST = DESCRIPTOR.message_types_by_name['DeleteNotebookRequest']
_DELETENOTEBOOKRESPONSE = DESCRIPTOR.message_types_by_name['DeleteNotebookResponse']
ListNotebooksRequest = _reflection.GeneratedProtocolMessageType('ListNotebooksRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTNOTEBOOKSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.notebook.v1.notebook_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebook.v1.ListNotebooksRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTNOTEBOOKSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebook.v1.notebook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebook.v1.ListNotebooksRequest)
  })
_sym_db.RegisterMessage(ListNotebooksRequest)
_sym_db.RegisterMessage(ListNotebooksRequest.LabelsEntry)

ListNotebooksResponse = _reflection.GeneratedProtocolMessageType('ListNotebooksResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTNOTEBOOKSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebook.v1.notebook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebook.v1.ListNotebooksResponse)
  })
_sym_db.RegisterMessage(ListNotebooksResponse)

NotebookResponse = _reflection.GeneratedProtocolMessageType('NotebookResponse', (_message.Message,), {
  'DESCRIPTOR' : _NOTEBOOKRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebook.v1.notebook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebook.v1.NotebookResponse)
  })
_sym_db.RegisterMessage(NotebookResponse)

CreateNotebookRequest = _reflection.GeneratedProtocolMessageType('CreateNotebookRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATENOTEBOOKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebook.v1.notebook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebook.v1.CreateNotebookRequest)
  })
_sym_db.RegisterMessage(CreateNotebookRequest)

CreateNotebookResponse = _reflection.GeneratedProtocolMessageType('CreateNotebookResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATENOTEBOOKRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebook.v1.notebook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebook.v1.CreateNotebookResponse)
  })
_sym_db.RegisterMessage(CreateNotebookResponse)

UpdateNotebookRequest = _reflection.GeneratedProtocolMessageType('UpdateNotebookRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATENOTEBOOKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebook.v1.notebook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebook.v1.UpdateNotebookRequest)
  })
_sym_db.RegisterMessage(UpdateNotebookRequest)

UpdateNotebookResponse = _reflection.GeneratedProtocolMessageType('UpdateNotebookResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATENOTEBOOKRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebook.v1.notebook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebook.v1.UpdateNotebookResponse)
  })
_sym_db.RegisterMessage(UpdateNotebookResponse)

GetNotebookRequest = _reflection.GeneratedProtocolMessageType('GetNotebookRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNOTEBOOKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebook.v1.notebook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebook.v1.GetNotebookRequest)
  })
_sym_db.RegisterMessage(GetNotebookRequest)

GetNotebookResponse = _reflection.GeneratedProtocolMessageType('GetNotebookResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETNOTEBOOKRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebook.v1.notebook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebook.v1.GetNotebookResponse)
  })
_sym_db.RegisterMessage(GetNotebookResponse)

DeleteNotebookRequest = _reflection.GeneratedProtocolMessageType('DeleteNotebookRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETENOTEBOOKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebook.v1.notebook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebook.v1.DeleteNotebookRequest)
  })
_sym_db.RegisterMessage(DeleteNotebookRequest)

DeleteNotebookResponse = _reflection.GeneratedProtocolMessageType('DeleteNotebookResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETENOTEBOOKRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebook.v1.notebook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebook.v1.DeleteNotebookResponse)
  })
_sym_db.RegisterMessage(DeleteNotebookResponse)

_NOTEBOOKSERVICE = DESCRIPTOR.services_by_name['NotebookService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z2github.com/metaprov/modelaapi/services/notebook/v1'
  _LISTNOTEBOOKSREQUEST_LABELSENTRY._options = None
  _LISTNOTEBOOKSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _NOTEBOOKSERVICE.methods_by_name['ListNotebooks']._options = None
  _NOTEBOOKSERVICE.methods_by_name['ListNotebooks']._serialized_options = b'\202\323\344\223\002\017\022\r/v1/notebooks'
  _NOTEBOOKSERVICE.methods_by_name['CreateNotebook']._options = None
  _NOTEBOOKSERVICE.methods_by_name['CreateNotebook']._serialized_options = b'\202\323\344\223\002\022\"\r/v1/notebooks:\001*'
  _NOTEBOOKSERVICE.methods_by_name['GetNotebook']._options = None
  _NOTEBOOKSERVICE.methods_by_name['GetNotebook']._serialized_options = b'\202\323\344\223\002\"\022 /v1/notebooks/{namespace}/{name}'
  _NOTEBOOKSERVICE.methods_by_name['UpdateNotebook']._options = None
  _NOTEBOOKSERVICE.methods_by_name['UpdateNotebook']._serialized_options = b'\202\323\344\223\002I\032D/v1/notebooks/{notebook.metadata.namespace}/{notebook.metadata.name}:\001*'
  _NOTEBOOKSERVICE.methods_by_name['DeleteNotebook']._options = None
  _NOTEBOOKSERVICE.methods_by_name['DeleteNotebook']._serialized_options = b'\202\323\344\223\002\"* /v1/notebooks/{namespace}/{name}'
  _LISTNOTEBOOKSREQUEST._serialized_start=323
  _LISTNOTEBOOKSREQUEST._serialized_end=570
  _LISTNOTEBOOKSREQUEST_LABELSENTRY._serialized_start=525
  _LISTNOTEBOOKSREQUEST_LABELSENTRY._serialized_end=570
  _LISTNOTEBOOKSRESPONSE._serialized_start=573
  _LISTNOTEBOOKSRESPONSE._serialized_end=712
  _NOTEBOOKRESPONSE._serialized_start=714
  _NOTEBOOKRESPONSE._serialized_end=732
  _CREATENOTEBOOKREQUEST._serialized_start=734
  _CREATENOTEBOOKREQUEST._serialized_end=843
  _CREATENOTEBOOKRESPONSE._serialized_start=845
  _CREATENOTEBOOKRESPONSE._serialized_end=869
  _UPDATENOTEBOOKREQUEST._serialized_start=872
  _UPDATENOTEBOOKREQUEST._serialized_end=1029
  _UPDATENOTEBOOKRESPONSE._serialized_start=1031
  _UPDATENOTEBOOKRESPONSE._serialized_end=1055
  _GETNOTEBOOKREQUEST._serialized_start=1057
  _GETNOTEBOOKREQUEST._serialized_end=1110
  _GETNOTEBOOKRESPONSE._serialized_start=1112
  _GETNOTEBOOKRESPONSE._serialized_end=1233
  _DELETENOTEBOOKREQUEST._serialized_start=1235
  _DELETENOTEBOOKREQUEST._serialized_end=1291
  _DELETENOTEBOOKRESPONSE._serialized_start=1293
  _DELETENOTEBOOKRESPONSE._serialized_end=1317
  _NOTEBOOKSERVICE._serialized_start=1320
  _NOTEBOOKSERVICE._serialized_end=2389
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/model/v1/model.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;github.com/metaprov/modelaapi/services/model/v1/model.proto\x12/github.com.metaprov.modelaapi.services.model.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1aHgithub.com/metaprov/modelaapi/pkg/apis/training/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\")\n\x1a\x43reateModelProfileResponse\x12\x0b\n\x03uri\x18\x03 \x01(\t\"<\n\x19\x43reateModelProfileRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\":\n\x17ListModelProfileRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"F\n\x16GetModelProfileRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\"j\n\x17GetModelProfileResponse\x12O\n\x07profile\x18\x01 \x01(\x0b\x32>.github.com.metaprov.modelaapi.services.common.v1.ModelProfile\"\xa2\x01\n\x14GetModelLogsResponse\x12]\n\x04logs\x18\x01 \x03(\x0b\x32O.github.com.metaprov.modelaapi.services.model.v1.GetModelLogsResponse.LogsEntry\x1a+\n\tLogsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"6\n\x13GetModelLogsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"d\n\x12\x43reateModelRequest\x12N\n\x05model\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\"\x15\n\x13\x43reateModelResponse\"d\n\x12UpdateModelRequest\x12N\n\x05model\x18\x05 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\"\x15\n\x13UpdateModelResponse\"p\n\x10GetModelResponse\x12N\n\x05model\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"4\n\x11\x41\x62ortModelRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x14\n\x12\x41\x62ortModelResponse\"4\n\x11PauseModelRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x14\n\x12PauseModelResponse\"5\n\x12ResumeModelRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x15\n\x13ResumeModelResponse\"8\n\x14\x43ompareModelsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\r\n\x05names\x18\x02 \x03(\t\"\x8b\x01\n\x15\x43ompareModelsResponse\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\r\n\x05names\x18\x02 \x03(\t\x12P\n\x08profiles\x18\x03 \x03(\x0b\x32>.github.com.metaprov.modelaapi.services.common.v1.ModelProfile\"X\n\x13\x43ompileModelRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06target\x18\x03 \x01(\t\x12\x10\n\x08\x63ompiler\x18\x04 \x01(\t\"8\n\x14\x43ompileModelResponse\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\r\n\x05names\x18\x02 \x01(\t\"y\n\x12\x44\x65ployModelRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tpredictor\x18\x03 \x01(\t\x12\x10\n\x08replicas\x18\x04 \x01(\x05\x12\x0f\n\x07traffic\x18\x05 \x01(\x05\x12\x0c\n\x04role\x18\x06 \x01(\t\"6\n\x13PublishModelRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x15\n\x13\x44\x65ployModelResponse\"\xee\x01\n\x11ListModelsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12^\n\x06labels\x18\x02 \x03(\x0b\x32N.github.com.metaprov.modelaapi.services.model.v1.ListModelsRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"i\n\x12ListModelsResponse\x12S\n\x06models\x18\x01 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelList\"2\n\x0fGetModelRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x13\n\x11UpdateModelResult\"5\n\x12\x44\x65leteModelRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x15\n\x13\x44\x65leteModelResponse\",\n\x14PublishModelResponse\x12\x14\n\x0cmodelTarHash\x18\x01 \x01(\t\"5\n\x12GetMisclassRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"a\n\x13GetMisclassResponse\x12J\n\x05table\x18\x01 \x01(\x0b\x32;.github.com.metaprov.modelaapi.services.common.v1.TableView\"7\n\x14\x44ownloadModelRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"$\n\x15\x44ownloadModelResponse\x12\x0b\n\x03raw\x18\x01 \x01(\x0c\"3\n\x10\x46lagModelRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x13\n\x11\x46lagModelResponse\"3\n\x10TestModelRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x13\n\x11TestModelResponse2\x84\x1e\n\x0cModelService\x12\xb4\x01\n\nListModels\x12\x42.github.com.metaprov.modelaapi.services.model.v1.ListModelsRequest\x1a\x43.github.com.metaprov.modelaapi.services.model.v1.ListModelsResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/v1/model/{namespace}\x12\xaf\x01\n\x0b\x43reateModel\x12\x43.github.com.metaprov.modelaapi.services.model.v1.CreateModelRequest\x1a\x44.github.com.metaprov.modelaapi.services.model.v1.CreateModelResponse\"\x15\x82\xd3\xe4\x93\x02\x0f\"\n/v1/models:\x01*\x12\xb6\x01\n\x08GetModel\x12@.github.com.metaprov.modelaapi.services.model.v1.GetModelRequest\x1a\x41.github.com.metaprov.modelaapi.services.model.v1.GetModelResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/v1/models/{namespace}/{name}\x12\xe0\x01\n\x0bUpdateModel\x12\x43.github.com.metaprov.modelaapi.services.model.v1.UpdateModelRequest\x1a\x44.github.com.metaprov.modelaapi.services.model.v1.UpdateModelResponse\"F\x82\xd3\xe4\x93\x02@\x1a;/v1/models/{model.metadata.namespace}/{model.metadata.name}:\x01*\x12\xbf\x01\n\x0b\x44\x65leteModel\x12\x43.github.com.metaprov.modelaapi.services.model.v1.DeleteModelRequest\x1a\x44.github.com.metaprov.modelaapi.services.model.v1.DeleteModelResponse\"%\x82\xd3\xe4\x93\x02\x1f*\x1d/v1/models/{namespace}/{name}\x12\xc9\x01\n\x0b\x44\x65ployModel\x12\x43.github.com.metaprov.modelaapi.services.model.v1.DeployModelRequest\x1a\x44.github.com.metaprov.modelaapi.services.model.v1.DeployModelResponse\"/\x82\xd3\xe4\x93\x02)\"$/v1/models/{namespace}/{name}:deploy:\x01*\x12\xcd\x01\n\x0cPublishModel\x12\x44.github.com.metaprov.modelaapi.services.model.v1.PublishModelRequest\x1a\x45.github.com.metaprov.modelaapi.services.model.v1.PublishModelResponse\"0\x82\xd3\xe4\x93\x02*\"%/v1/models/{namespace}/{name}:publish:\x01*\x12\xdc\x01\n\x12\x43reateModelProfile\x12J.github.com.metaprov.modelaapi.services.model.v1.CreateModelProfileRequest\x1aK.github.com.metaprov.modelaapi.services.model.v1.CreateModelProfileResponse\"-\x82\xd3\xe4\x93\x02\'\"%/v1/models/{namespace}/{name}:profile\x12\xd3\x01\n\x0fGetModelProfile\x12G.github.com.metaprov.modelaapi.services.model.v1.GetModelProfileRequest\x1aH.github.com.metaprov.modelaapi.services.model.v1.GetModelProfileResponse\"-\x82\xd3\xe4\x93\x02\'\"%/v1/models/{namespace}/{name}:profile\x12\xcd\x01\n\x10GetModelMisclass\x12\x43.github.com.metaprov.modelaapi.services.model.v1.GetMisclassRequest\x1a\x44.github.com.metaprov.modelaapi.services.model.v1.GetMisclassResponse\".\x82\xd3\xe4\x93\x02(\x12&/v1/models/{namespace}/{name}:misclass\x12\xc7\x01\n\x0cGetModelLogs\x12\x44.github.com.metaprov.modelaapi.services.model.v1.GetModelLogsRequest\x1a\x45.github.com.metaprov.modelaapi.services.model.v1.GetModelLogsResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/v1/models/{namespace}/{name}:logs\x12\xc2\x01\n\nAbortModel\x12\x42.github.com.metaprov.modelaapi.services.model.v1.AbortModelRequest\x1a\x43.github.com.metaprov.modelaapi.services.model.v1.AbortModelResponse\"+\x82\xd3\xe4\x93\x02%\"#/v1/models/{namespace}/{name}:abort\x12\xc2\x01\n\nPauseModel\x12\x42.github.com.metaprov.modelaapi.services.model.v1.PauseModelRequest\x1a\x43.github.com.metaprov.modelaapi.services.model.v1.PauseModelResponse\"+\x82\xd3\xe4\x93\x02%\"#/v1/models/{namespace}/{name}:pause\x12\xc6\x01\n\x0bResumeModel\x12\x43.github.com.metaprov.modelaapi.services.model.v1.ResumeModelRequest\x1a\x44.github.com.metaprov.modelaapi.services.model.v1.ResumeModelResponse\",\x82\xd3\xe4\x93\x02&\"$/v1/models/{namespace}/{name}:resume\x12\xce\x01\n\rCompareModels\x12\x45.github.com.metaprov.modelaapi.services.model.v1.CompareModelsRequest\x1a\x46.github.com.metaprov.modelaapi.services.model.v1.CompareModelsResponse\".\x82\xd3\xe4\x93\x02(\"&/v1/models/{namespace}/{names}:compare\x12\xca\x01\n\x0c\x43ompileModel\x12\x44.github.com.metaprov.modelaapi.services.model.v1.CompileModelRequest\x1a\x45.github.com.metaprov.modelaapi.services.model.v1.CompileModelResponse\"-\x82\xd3\xe4\x93\x02\'\"%/v1/models/{namespace}/{name}:compile\x12\xce\x01\n\rDownloadModel\x12\x45.github.com.metaprov.modelaapi.services.model.v1.DownloadModelRequest\x1a\x46.github.com.metaprov.modelaapi.services.model.v1.DownloadModelResponse\".\x82\xd3\xe4\x93\x02(\"&/v1/models/{namespace}/{name}:download\x12\xbe\x01\n\tFlagModel\x12\x41.github.com.metaprov.modelaapi.services.model.v1.FlagModelRequest\x1a\x42.github.com.metaprov.modelaapi.services.model.v1.FlagModelResponse\"*\x82\xd3\xe4\x93\x02$\"\"/v1/models/{namespace}/{name}:flag\x12\xbe\x01\n\tTestModel\x12\x41.github.com.metaprov.modelaapi.services.model.v1.TestModelRequest\x1a\x42.github.com.metaprov.modelaapi.services.model.v1.TestModelResponse\"*\x82\xd3\xe4\x93\x02$\"\"/v1/models/{namespace}/{name}:testB1Z/github.com/metaprov/modelaapi/services/model/v1b\x06proto3')



_CREATEMODELPROFILERESPONSE = DESCRIPTOR.message_types_by_name['CreateModelProfileResponse']
_CREATEMODELPROFILEREQUEST = DESCRIPTOR.message_types_by_name['CreateModelProfileRequest']
_LISTMODELPROFILEREQUEST = DESCRIPTOR.message_types_by_name['ListModelProfileRequest']
_GETMODELPROFILEREQUEST = DESCRIPTOR.message_types_by_name['GetModelProfileRequest']
_GETMODELPROFILERESPONSE = DESCRIPTOR.message_types_by_name['GetModelProfileResponse']
_GETMODELLOGSRESPONSE = DESCRIPTOR.message_types_by_name['GetModelLogsResponse']
_GETMODELLOGSRESPONSE_LOGSENTRY = _GETMODELLOGSRESPONSE.nested_types_by_name['LogsEntry']
_GETMODELLOGSREQUEST = DESCRIPTOR.message_types_by_name['GetModelLogsRequest']
_CREATEMODELREQUEST = DESCRIPTOR.message_types_by_name['CreateModelRequest']
_CREATEMODELRESPONSE = DESCRIPTOR.message_types_by_name['CreateModelResponse']
_UPDATEMODELREQUEST = DESCRIPTOR.message_types_by_name['UpdateModelRequest']
_UPDATEMODELRESPONSE = DESCRIPTOR.message_types_by_name['UpdateModelResponse']
_GETMODELRESPONSE = DESCRIPTOR.message_types_by_name['GetModelResponse']
_ABORTMODELREQUEST = DESCRIPTOR.message_types_by_name['AbortModelRequest']
_ABORTMODELRESPONSE = DESCRIPTOR.message_types_by_name['AbortModelResponse']
_PAUSEMODELREQUEST = DESCRIPTOR.message_types_by_name['PauseModelRequest']
_PAUSEMODELRESPONSE = DESCRIPTOR.message_types_by_name['PauseModelResponse']
_RESUMEMODELREQUEST = DESCRIPTOR.message_types_by_name['ResumeModelRequest']
_RESUMEMODELRESPONSE = DESCRIPTOR.message_types_by_name['ResumeModelResponse']
_COMPAREMODELSREQUEST = DESCRIPTOR.message_types_by_name['CompareModelsRequest']
_COMPAREMODELSRESPONSE = DESCRIPTOR.message_types_by_name['CompareModelsResponse']
_COMPILEMODELREQUEST = DESCRIPTOR.message_types_by_name['CompileModelRequest']
_COMPILEMODELRESPONSE = DESCRIPTOR.message_types_by_name['CompileModelResponse']
_DEPLOYMODELREQUEST = DESCRIPTOR.message_types_by_name['DeployModelRequest']
_PUBLISHMODELREQUEST = DESCRIPTOR.message_types_by_name['PublishModelRequest']
_DEPLOYMODELRESPONSE = DESCRIPTOR.message_types_by_name['DeployModelResponse']
_LISTMODELSREQUEST = DESCRIPTOR.message_types_by_name['ListModelsRequest']
_LISTMODELSREQUEST_LABELSENTRY = _LISTMODELSREQUEST.nested_types_by_name['LabelsEntry']
_LISTMODELSRESPONSE = DESCRIPTOR.message_types_by_name['ListModelsResponse']
_GETMODELREQUEST = DESCRIPTOR.message_types_by_name['GetModelRequest']
_UPDATEMODELRESULT = DESCRIPTOR.message_types_by_name['UpdateModelResult']
_DELETEMODELREQUEST = DESCRIPTOR.message_types_by_name['DeleteModelRequest']
_DELETEMODELRESPONSE = DESCRIPTOR.message_types_by_name['DeleteModelResponse']
_PUBLISHMODELRESPONSE = DESCRIPTOR.message_types_by_name['PublishModelResponse']
_GETMISCLASSREQUEST = DESCRIPTOR.message_types_by_name['GetMisclassRequest']
_GETMISCLASSRESPONSE = DESCRIPTOR.message_types_by_name['GetMisclassResponse']
_DOWNLOADMODELREQUEST = DESCRIPTOR.message_types_by_name['DownloadModelRequest']
_DOWNLOADMODELRESPONSE = DESCRIPTOR.message_types_by_name['DownloadModelResponse']
_FLAGMODELREQUEST = DESCRIPTOR.message_types_by_name['FlagModelRequest']
_FLAGMODELRESPONSE = DESCRIPTOR.message_types_by_name['FlagModelResponse']
_TESTMODELREQUEST = DESCRIPTOR.message_types_by_name['TestModelRequest']
_TESTMODELRESPONSE = DESCRIPTOR.message_types_by_name['TestModelResponse']
CreateModelProfileResponse = _reflection.GeneratedProtocolMessageType('CreateModelProfileResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELPROFILERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.CreateModelProfileResponse)
  })
_sym_db.RegisterMessage(CreateModelProfileResponse)

CreateModelProfileRequest = _reflection.GeneratedProtocolMessageType('CreateModelProfileRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELPROFILEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.CreateModelProfileRequest)
  })
_sym_db.RegisterMessage(CreateModelProfileRequest)

ListModelProfileRequest = _reflection.GeneratedProtocolMessageType('ListModelProfileRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELPROFILEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.ListModelProfileRequest)
  })
_sym_db.RegisterMessage(ListModelProfileRequest)

GetModelProfileRequest = _reflection.GeneratedProtocolMessageType('GetModelProfileRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELPROFILEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.GetModelProfileRequest)
  })
_sym_db.RegisterMessage(GetModelProfileRequest)

GetModelProfileResponse = _reflection.GeneratedProtocolMessageType('GetModelProfileResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELPROFILERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.GetModelProfileResponse)
  })
_sym_db.RegisterMessage(GetModelProfileResponse)

GetModelLogsResponse = _reflection.GeneratedProtocolMessageType('GetModelLogsResponse', (_message.Message,), {

  'LogsEntry' : _reflection.GeneratedProtocolMessageType('LogsEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETMODELLOGSRESPONSE_LOGSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.GetModelLogsResponse.LogsEntry)
    })
  ,
  'DESCRIPTOR' : _GETMODELLOGSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.GetModelLogsResponse)
  })
_sym_db.RegisterMessage(GetModelLogsResponse)
_sym_db.RegisterMessage(GetModelLogsResponse.LogsEntry)

GetModelLogsRequest = _reflection.GeneratedProtocolMessageType('GetModelLogsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELLOGSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.GetModelLogsRequest)
  })
_sym_db.RegisterMessage(GetModelLogsRequest)

CreateModelRequest = _reflection.GeneratedProtocolMessageType('CreateModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.CreateModelRequest)
  })
_sym_db.RegisterMessage(CreateModelRequest)

CreateModelResponse = _reflection.GeneratedProtocolMessageType('CreateModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.CreateModelResponse)
  })
_sym_db.RegisterMessage(CreateModelResponse)

UpdateModelRequest = _reflection.GeneratedProtocolMessageType('UpdateModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.UpdateModelRequest)
  })
_sym_db.RegisterMessage(UpdateModelRequest)

UpdateModelResponse = _reflection.GeneratedProtocolMessageType('UpdateModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.UpdateModelResponse)
  })
_sym_db.RegisterMessage(UpdateModelResponse)

GetModelResponse = _reflection.GeneratedProtocolMessageType('GetModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.GetModelResponse)
  })
_sym_db.RegisterMessage(GetModelResponse)

AbortModelRequest = _reflection.GeneratedProtocolMessageType('AbortModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _ABORTMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.AbortModelRequest)
  })
_sym_db.RegisterMessage(AbortModelRequest)

AbortModelResponse = _reflection.GeneratedProtocolMessageType('AbortModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _ABORTMODELRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.AbortModelResponse)
  })
_sym_db.RegisterMessage(AbortModelResponse)

PauseModelRequest = _reflection.GeneratedProtocolMessageType('PauseModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.PauseModelRequest)
  })
_sym_db.RegisterMessage(PauseModelRequest)

PauseModelResponse = _reflection.GeneratedProtocolMessageType('PauseModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEMODELRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.PauseModelResponse)
  })
_sym_db.RegisterMessage(PauseModelResponse)

ResumeModelRequest = _reflection.GeneratedProtocolMessageType('ResumeModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.ResumeModelRequest)
  })
_sym_db.RegisterMessage(ResumeModelRequest)

ResumeModelResponse = _reflection.GeneratedProtocolMessageType('ResumeModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEMODELRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.ResumeModelResponse)
  })
_sym_db.RegisterMessage(ResumeModelResponse)

CompareModelsRequest = _reflection.GeneratedProtocolMessageType('CompareModelsRequest', (_message.Message,), {
  'DESCRIPTOR' : _COMPAREMODELSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.CompareModelsRequest)
  })
_sym_db.RegisterMessage(CompareModelsRequest)

CompareModelsResponse = _reflection.GeneratedProtocolMessageType('CompareModelsResponse', (_message.Message,), {
  'DESCRIPTOR' : _COMPAREMODELSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.CompareModelsResponse)
  })
_sym_db.RegisterMessage(CompareModelsResponse)

CompileModelRequest = _reflection.GeneratedProtocolMessageType('CompileModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _COMPILEMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.CompileModelRequest)
  })
_sym_db.RegisterMessage(CompileModelRequest)

CompileModelResponse = _reflection.GeneratedProtocolMessageType('CompileModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _COMPILEMODELRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.CompileModelResponse)
  })
_sym_db.RegisterMessage(CompileModelResponse)

DeployModelRequest = _reflection.GeneratedProtocolMessageType('DeployModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.DeployModelRequest)
  })
_sym_db.RegisterMessage(DeployModelRequest)

PublishModelRequest = _reflection.GeneratedProtocolMessageType('PublishModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _PUBLISHMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.PublishModelRequest)
  })
_sym_db.RegisterMessage(PublishModelRequest)

DeployModelResponse = _reflection.GeneratedProtocolMessageType('DeployModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYMODELRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.DeployModelResponse)
  })
_sym_db.RegisterMessage(DeployModelResponse)

ListModelsRequest = _reflection.GeneratedProtocolMessageType('ListModelsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTMODELSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.ListModelsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTMODELSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.ListModelsRequest)
  })
_sym_db.RegisterMessage(ListModelsRequest)
_sym_db.RegisterMessage(ListModelsRequest.LabelsEntry)

ListModelsResponse = _reflection.GeneratedProtocolMessageType('ListModelsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.ListModelsResponse)
  })
_sym_db.RegisterMessage(ListModelsResponse)

GetModelRequest = _reflection.GeneratedProtocolMessageType('GetModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.GetModelRequest)
  })
_sym_db.RegisterMessage(GetModelRequest)

UpdateModelResult = _reflection.GeneratedProtocolMessageType('UpdateModelResult', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELRESULT,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.UpdateModelResult)
  })
_sym_db.RegisterMessage(UpdateModelResult)

DeleteModelRequest = _reflection.GeneratedProtocolMessageType('DeleteModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.DeleteModelRequest)
  })
_sym_db.RegisterMessage(DeleteModelRequest)

DeleteModelResponse = _reflection.GeneratedProtocolMessageType('DeleteModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.DeleteModelResponse)
  })
_sym_db.RegisterMessage(DeleteModelResponse)

PublishModelResponse = _reflection.GeneratedProtocolMessageType('PublishModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _PUBLISHMODELRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.PublishModelResponse)
  })
_sym_db.RegisterMessage(PublishModelResponse)

GetMisclassRequest = _reflection.GeneratedProtocolMessageType('GetMisclassRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMISCLASSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.GetMisclassRequest)
  })
_sym_db.RegisterMessage(GetMisclassRequest)

GetMisclassResponse = _reflection.GeneratedProtocolMessageType('GetMisclassResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMISCLASSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.GetMisclassResponse)
  })
_sym_db.RegisterMessage(GetMisclassResponse)

DownloadModelRequest = _reflection.GeneratedProtocolMessageType('DownloadModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.DownloadModelRequest)
  })
_sym_db.RegisterMessage(DownloadModelRequest)

DownloadModelResponse = _reflection.GeneratedProtocolMessageType('DownloadModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADMODELRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.DownloadModelResponse)
  })
_sym_db.RegisterMessage(DownloadModelResponse)

FlagModelRequest = _reflection.GeneratedProtocolMessageType('FlagModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _FLAGMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.FlagModelRequest)
  })
_sym_db.RegisterMessage(FlagModelRequest)

FlagModelResponse = _reflection.GeneratedProtocolMessageType('FlagModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _FLAGMODELRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.FlagModelResponse)
  })
_sym_db.RegisterMessage(FlagModelResponse)

TestModelRequest = _reflection.GeneratedProtocolMessageType('TestModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _TESTMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.TestModelRequest)
  })
_sym_db.RegisterMessage(TestModelRequest)

TestModelResponse = _reflection.GeneratedProtocolMessageType('TestModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _TESTMODELRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.TestModelResponse)
  })
_sym_db.RegisterMessage(TestModelResponse)

_MODELSERVICE = DESCRIPTOR.services_by_name['ModelService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z/github.com/metaprov/modelaapi/services/model/v1'
  _GETMODELLOGSRESPONSE_LOGSENTRY._options = None
  _GETMODELLOGSRESPONSE_LOGSENTRY._serialized_options = b'8\001'
  _LISTMODELSREQUEST_LABELSENTRY._options = None
  _LISTMODELSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _MODELSERVICE.methods_by_name['ListModels']._options = None
  _MODELSERVICE.methods_by_name['ListModels']._serialized_options = b'\202\323\344\223\002\027\022\025/v1/model/{namespace}'
  _MODELSERVICE.methods_by_name['CreateModel']._options = None
  _MODELSERVICE.methods_by_name['CreateModel']._serialized_options = b'\202\323\344\223\002\017\"\n/v1/models:\001*'
  _MODELSERVICE.methods_by_name['GetModel']._options = None
  _MODELSERVICE.methods_by_name['GetModel']._serialized_options = b'\202\323\344\223\002\037\022\035/v1/models/{namespace}/{name}'
  _MODELSERVICE.methods_by_name['UpdateModel']._options = None
  _MODELSERVICE.methods_by_name['UpdateModel']._serialized_options = b'\202\323\344\223\002@\032;/v1/models/{model.metadata.namespace}/{model.metadata.name}:\001*'
  _MODELSERVICE.methods_by_name['DeleteModel']._options = None
  _MODELSERVICE.methods_by_name['DeleteModel']._serialized_options = b'\202\323\344\223\002\037*\035/v1/models/{namespace}/{name}'
  _MODELSERVICE.methods_by_name['DeployModel']._options = None
  _MODELSERVICE.methods_by_name['DeployModel']._serialized_options = b'\202\323\344\223\002)\"$/v1/models/{namespace}/{name}:deploy:\001*'
  _MODELSERVICE.methods_by_name['PublishModel']._options = None
  _MODELSERVICE.methods_by_name['PublishModel']._serialized_options = b'\202\323\344\223\002*\"%/v1/models/{namespace}/{name}:publish:\001*'
  _MODELSERVICE.methods_by_name['CreateModelProfile']._options = None
  _MODELSERVICE.methods_by_name['CreateModelProfile']._serialized_options = b'\202\323\344\223\002\'\"%/v1/models/{namespace}/{name}:profile'
  _MODELSERVICE.methods_by_name['GetModelProfile']._options = None
  _MODELSERVICE.methods_by_name['GetModelProfile']._serialized_options = b'\202\323\344\223\002\'\"%/v1/models/{namespace}/{name}:profile'
  _MODELSERVICE.methods_by_name['GetModelMisclass']._options = None
  _MODELSERVICE.methods_by_name['GetModelMisclass']._serialized_options = b'\202\323\344\223\002(\022&/v1/models/{namespace}/{name}:misclass'
  _MODELSERVICE.methods_by_name['GetModelLogs']._options = None
  _MODELSERVICE.methods_by_name['GetModelLogs']._serialized_options = b'\202\323\344\223\002$\022\"/v1/models/{namespace}/{name}:logs'
  _MODELSERVICE.methods_by_name['AbortModel']._options = None
  _MODELSERVICE.methods_by_name['AbortModel']._serialized_options = b'\202\323\344\223\002%\"#/v1/models/{namespace}/{name}:abort'
  _MODELSERVICE.methods_by_name['PauseModel']._options = None
  _MODELSERVICE.methods_by_name['PauseModel']._serialized_options = b'\202\323\344\223\002%\"#/v1/models/{namespace}/{name}:pause'
  _MODELSERVICE.methods_by_name['ResumeModel']._options = None
  _MODELSERVICE.methods_by_name['ResumeModel']._serialized_options = b'\202\323\344\223\002&\"$/v1/models/{namespace}/{name}:resume'
  _MODELSERVICE.methods_by_name['CompareModels']._options = None
  _MODELSERVICE.methods_by_name['CompareModels']._serialized_options = b'\202\323\344\223\002(\"&/v1/models/{namespace}/{names}:compare'
  _MODELSERVICE.methods_by_name['CompileModel']._options = None
  _MODELSERVICE.methods_by_name['CompileModel']._serialized_options = b'\202\323\344\223\002\'\"%/v1/models/{namespace}/{name}:compile'
  _MODELSERVICE.methods_by_name['DownloadModel']._options = None
  _MODELSERVICE.methods_by_name['DownloadModel']._serialized_options = b'\202\323\344\223\002(\"&/v1/models/{namespace}/{name}:download'
  _MODELSERVICE.methods_by_name['FlagModel']._options = None
  _MODELSERVICE.methods_by_name['FlagModel']._serialized_options = b'\202\323\344\223\002$\"\"/v1/models/{namespace}/{name}:flag'
  _MODELSERVICE.methods_by_name['TestModel']._options = None
  _MODELSERVICE.methods_by_name['TestModel']._serialized_options = b'\202\323\344\223\002$\"\"/v1/models/{namespace}/{name}:test'
  _CREATEMODELPROFILERESPONSE._serialized_start=313
  _CREATEMODELPROFILERESPONSE._serialized_end=354
  _CREATEMODELPROFILEREQUEST._serialized_start=356
  _CREATEMODELPROFILEREQUEST._serialized_end=416
  _LISTMODELPROFILEREQUEST._serialized_start=418
  _LISTMODELPROFILEREQUEST._serialized_end=476
  _GETMODELPROFILEREQUEST._serialized_start=478
  _GETMODELPROFILEREQUEST._serialized_end=548
  _GETMODELPROFILERESPONSE._serialized_start=550
  _GETMODELPROFILERESPONSE._serialized_end=656
  _GETMODELLOGSRESPONSE._serialized_start=659
  _GETMODELLOGSRESPONSE._serialized_end=821
  _GETMODELLOGSRESPONSE_LOGSENTRY._serialized_start=778
  _GETMODELLOGSRESPONSE_LOGSENTRY._serialized_end=821
  _GETMODELLOGSREQUEST._serialized_start=823
  _GETMODELLOGSREQUEST._serialized_end=877
  _CREATEMODELREQUEST._serialized_start=879
  _CREATEMODELREQUEST._serialized_end=979
  _CREATEMODELRESPONSE._serialized_start=981
  _CREATEMODELRESPONSE._serialized_end=1002
  _UPDATEMODELREQUEST._serialized_start=1004
  _UPDATEMODELREQUEST._serialized_end=1104
  _UPDATEMODELRESPONSE._serialized_start=1106
  _UPDATEMODELRESPONSE._serialized_end=1127
  _GETMODELRESPONSE._serialized_start=1129
  _GETMODELRESPONSE._serialized_end=1241
  _ABORTMODELREQUEST._serialized_start=1243
  _ABORTMODELREQUEST._serialized_end=1295
  _ABORTMODELRESPONSE._serialized_start=1297
  _ABORTMODELRESPONSE._serialized_end=1317
  _PAUSEMODELREQUEST._serialized_start=1319
  _PAUSEMODELREQUEST._serialized_end=1371
  _PAUSEMODELRESPONSE._serialized_start=1373
  _PAUSEMODELRESPONSE._serialized_end=1393
  _RESUMEMODELREQUEST._serialized_start=1395
  _RESUMEMODELREQUEST._serialized_end=1448
  _RESUMEMODELRESPONSE._serialized_start=1450
  _RESUMEMODELRESPONSE._serialized_end=1471
  _COMPAREMODELSREQUEST._serialized_start=1473
  _COMPAREMODELSREQUEST._serialized_end=1529
  _COMPAREMODELSRESPONSE._serialized_start=1532
  _COMPAREMODELSRESPONSE._serialized_end=1671
  _COMPILEMODELREQUEST._serialized_start=1673
  _COMPILEMODELREQUEST._serialized_end=1761
  _COMPILEMODELRESPONSE._serialized_start=1763
  _COMPILEMODELRESPONSE._serialized_end=1819
  _DEPLOYMODELREQUEST._serialized_start=1821
  _DEPLOYMODELREQUEST._serialized_end=1942
  _PUBLISHMODELREQUEST._serialized_start=1944
  _PUBLISHMODELREQUEST._serialized_end=1998
  _DEPLOYMODELRESPONSE._serialized_start=2000
  _DEPLOYMODELRESPONSE._serialized_end=2021
  _LISTMODELSREQUEST._serialized_start=2024
  _LISTMODELSREQUEST._serialized_end=2262
  _LISTMODELSREQUEST_LABELSENTRY._serialized_start=2217
  _LISTMODELSREQUEST_LABELSENTRY._serialized_end=2262
  _LISTMODELSRESPONSE._serialized_start=2264
  _LISTMODELSRESPONSE._serialized_end=2369
  _GETMODELREQUEST._serialized_start=2371
  _GETMODELREQUEST._serialized_end=2421
  _UPDATEMODELRESULT._serialized_start=2423
  _UPDATEMODELRESULT._serialized_end=2442
  _DELETEMODELREQUEST._serialized_start=2444
  _DELETEMODELREQUEST._serialized_end=2497
  _DELETEMODELRESPONSE._serialized_start=2499
  _DELETEMODELRESPONSE._serialized_end=2520
  _PUBLISHMODELRESPONSE._serialized_start=2522
  _PUBLISHMODELRESPONSE._serialized_end=2566
  _GETMISCLASSREQUEST._serialized_start=2568
  _GETMISCLASSREQUEST._serialized_end=2621
  _GETMISCLASSRESPONSE._serialized_start=2623
  _GETMISCLASSRESPONSE._serialized_end=2720
  _DOWNLOADMODELREQUEST._serialized_start=2722
  _DOWNLOADMODELREQUEST._serialized_end=2777
  _DOWNLOADMODELRESPONSE._serialized_start=2779
  _DOWNLOADMODELRESPONSE._serialized_end=2815
  _FLAGMODELREQUEST._serialized_start=2817
  _FLAGMODELREQUEST._serialized_end=2868
  _FLAGMODELRESPONSE._serialized_start=2870
  _FLAGMODELRESPONSE._serialized_end=2889
  _TESTMODELREQUEST._serialized_start=2891
  _TESTMODELREQUEST._serialized_end=2942
  _TESTMODELRESPONSE._serialized_start=2944
  _TESTMODELRESPONSE._serialized_end=2963
  _MODELSERVICE._serialized_start=2966
  _MODELSERVICE._serialized_end=6810
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.labelingpipeline.v1 import labelingpipeline_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipeline_dot_v1_dot_labelingpipeline__pb2


class LabelingPipelineServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListLabelingPipelines = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.labelingpipeline.v1.LabelingPipelineService/ListLabelingPipelines',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipeline_dot_v1_dot_labelingpipeline__pb2.ListLabelingPipelineRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipeline_dot_v1_dot_labelingpipeline__pb2.ListLabelingPipelineResponse.FromString,
                )
        self.CreateLabelingPipeline = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.labelingpipeline.v1.LabelingPipelineService/CreateLabelingPipeline',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipeline_dot_v1_dot_labelingpipeline__pb2.CreateLabelingPipelineRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipeline_dot_v1_dot_labelingpipeline__pb2.CreateLabelingPipelineResponse.FromString,
                )
        self.GetLabelingPipeline = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.labelingpipeline.v1.LabelingPipelineService/GetLabelingPipeline',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipeline_dot_v1_dot_labelingpipeline__pb2.GetLabelingPipelineRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipeline_dot_v1_dot_labelingpipeline__pb2.GetLabelingPipelineResponse.FromString,
                )
        self.UpdateLabelingPipeline = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.labelingpipeline.v1.LabelingPipelineService/UpdateLabelingPipeline',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipeline_dot_v1_dot_labelingpipeline__pb2.UpdateLabelingPipelineRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipeline_dot_v1_dot_labelingpipeline__pb2.UpdateLabelingPipelineResponse.FromString,
                )
        self.DeleteLabelingPipeline = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.labelingpipeline.v1.LabelingPipelineService/DeleteLabelingPipeline',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipeline_dot_v1_dot_labelingpipeline__pb2.DeleteLabelingPipelineRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipeline_dot_v1_dot_labelingpipeline__pb2.DeleteLabelingPipelineResponse.FromString,
                )
        self.PauseLabelingPipeline = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.labelingpipeline.v1.LabelingPipelineService/PauseLabelingPipeline',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipeline_dot_v1_dot_labelingpipeline__pb2.PauseLabelingPipelineRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipeline_dot_v1_dot_labelingpipeline__pb2.PauseLabelingPipelineResponse.FromString,
                )
        self.ResumeLabelingPipeline = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.labelingpipeline.v1.LabelingPipelineService/ResumeLabelingPipeline',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipeline_dot_v1_dot_labelingpipeline__pb2.ResumeLabelingPipelineRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipeline_dot_v1_dot_labelingpipeline__pb2.ResumeLabelingPipelineResponse.FromString,
                )


class LabelingPipelineServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListLabelingPipelines(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateLabelingPipeline(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLabelingPipeline(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateLabelingPipeline(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteLabelingPipeline(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PauseLabelingPipeline(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResumeLabelingPipeline(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_LabelingPipelineServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListLabelingPipelines': grpc.unary_unary_rpc_method_handler(
                    servicer.ListLabelingPipelines,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipeline_dot_v1_dot_labelingpipeline__pb2.ListLabelingPipelineRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipeline_dot_v1_dot_labelingpipeline__pb2.ListLabelingPipelineResponse.SerializeToString,
            ),
            'CreateLabelingPipeline': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateLabelingPipeline,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipeline_dot_v1_dot_labelingpipeline__pb2.CreateLabelingPipelineRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipeline_dot_v1_dot_labelingpipeline__pb2.CreateLabelingPipelineResponse.SerializeToString,
            ),
            'GetLabelingPipeline': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLabelingPipeline,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipeline_dot_v1_dot_labelingpipeline__pb2.GetLabelingPipelineRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipeline_dot_v1_dot_labelingpipeline__pb2.GetLabelingPipelineResponse.SerializeToString,
            ),
            'UpdateLabelingPipeline': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateLabelingPipeline,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipeline_dot_v1_dot_labelingpipeline__pb2.UpdateLabelingPipelineRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipeline_dot_v1_dot_labelingpipeline__pb2.UpdateLabelingPipelineResponse.SerializeToString,
            ),
            'DeleteLabelingPipeline': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteLabelingPipeline,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipeline_dot_v1_dot_labelingpipeline__pb2.DeleteLabelingPipelineRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipeline_dot_v1_dot_labelingpipeline__pb2.DeleteLabelingPipelineResponse.SerializeToString,
            ),
            'PauseLabelingPipeline': grpc.unary_unary_rpc_method_handler(
                    servicer.PauseLabelingPipeline,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipeline_dot_v1_dot_labelingpipeline__pb2.PauseLabelingPipelineRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipeline_dot_v1_dot_labelingpipeline__pb2.PauseLabelingPipelineResponse.SerializeToString,
            ),
            'ResumeLabelingPipeline': grpc.unary_unary_rpc_method_handler(
                    servicer.ResumeLabelingPipeline,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipeline_dot_v1_dot_labelingpipeline__pb2.ResumeLabelingPipelineRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipeline_dot_v1_dot_labelingpipeline__pb2.ResumeLabelingPipelineResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.labelingpipeline.v1.LabelingPipelineService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class LabelingPipelineService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListLabelingPipelines(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.labelingpipeline.v1.LabelingPipelineService/ListLabelingPipelines',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipeline_dot_v1_dot_labelingpipeline__pb2.ListLabelingPipelineRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipeline_dot_v1_dot_labelingpipeline__pb2.ListLabelingPipelineResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateLabelingPipeline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.labelingpipeline.v1.LabelingPipelineService/CreateLabelingPipeline',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipeline_dot_v1_dot_labelingpipeline__pb2.CreateLabelingPipelineRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipeline_dot_v1_dot_labelingpipeline__pb2.CreateLabelingPipelineResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLabelingPipeline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.labelingpipeline.v1.LabelingPipelineService/GetLabelingPipeline',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipeline_dot_v1_dot_labelingpipeline__pb2.GetLabelingPipelineRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipeline_dot_v1_dot_labelingpipeline__pb2.GetLabelingPipelineResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateLabelingPipeline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.labelingpipeline.v1.LabelingPipelineService/UpdateLabelingPipeline',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipeline_dot_v1_dot_labelingpipeline__pb2.UpdateLabelingPipelineRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipeline_dot_v1_dot_labelingpipeline__pb2.UpdateLabelingPipelineResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteLabelingPipeline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.labelingpipeline.v1.LabelingPipelineService/DeleteLabelingPipeline',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipeline_dot_v1_dot_labelingpipeline__pb2.DeleteLabelingPipelineRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipeline_dot_v1_dot_labelingpipeline__pb2.DeleteLabelingPipelineResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PauseLabelingPipeline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.labelingpipeline.v1.LabelingPipelineService/PauseLabelingPipeline',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipeline_dot_v1_dot_labelingpipeline__pb2.PauseLabelingPipelineRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipeline_dot_v1_dot_labelingpipeline__pb2.PauseLabelingPipelineResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResumeLabelingPipeline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.labelingpipeline.v1.LabelingPipelineService/ResumeLabelingPipeline',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipeline_dot_v1_dot_labelingpipeline__pb2.ResumeLabelingPipelineRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_labelingpipeline_dot_v1_dot_labelingpipeline__pb2.ResumeLabelingPipelineResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/review/v1/review.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/review/v1/review.proto',
  package='github.com.metaprov.modelaapi.services.review.v1',
  syntax='proto3',
  serialized_options=b'Z6github.com/metaprov/modelaapi/services/review/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nIgithub.com/metaprov/modelaapi/services/review/v1/review.proto\x12\x36github.com.metaprov.modelaapi.services.review.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/team/v1alpha1/generated.proto\x1a\x1cgoogle/api/annotations.proto\"\xd4\x01\n\x16GetReviewRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12j\n\x06labels\x18\x03 \x03(\x0b\x32Z.github.com.metaprov.modelaapi.services.review.v1.GetReviewRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"y\n\x17GetReviewResponse\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Review\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"m\n\x19\x43reateReviewRequest\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Review\"\x1c\n\x1a\x43reateReviewResponse\"m\n\x19UpdateReviewRequest\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Review\"\x1c\n\x1aUpdateReviewResponse\"\xda\x01\n\x19\x44\x65leteReviewRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12m\n\x06labels\x18\x03 \x03(\x0b\x32].github.com.metaprov.modelaapi.services.review.v1.DeleteReviewRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x1c\n\x1a\x44\x65leteReviewResponse\"\xef\x01\n\x17ListReviewRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12k\n\x06labels\x18\x02 \x03(\x0b\x32[.github.com.metaprov.modelaapi.services.review.v1.ListReviewRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8a\x01\n\x18ListReviewResponse\x12U\n\x05items\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.ReviewList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xe7\t\n\x13\x43onversationService\x12\xe7\x01\n\x11ListReviews\x12O.github.com.metaprov.modelaapi.services.review.v1.ListReviewRequest\x1aP.github.com.metaprov.modelaapi.services.review.v1.ListReviewResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/api/v1alpha1/reviews/{namespace}\x12\xe3\x01\n\x12\x43reateReview\x12Q.github.com.metaprov.modelaapi.services.review.v1.CreateReviewRequest\x1aR.github.com.metaprov.modelaapi.services.review.v1.CreateReviewResponse\"&\x82\xd3\xe4\x93\x02 \"\x1b/api/v1alpha1/reviews:\x01*\x12\xea\x01\n\x0fGetReview\x12N.github.com.metaprov.modelaapi.services.review.v1.GetReviewRequest\x1aO.github.com.metaprov.modelaapi.services.review.v1.GetReviewResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./api/v1alpha1/reviews/{namespace}/{name}\x12\xa2\x02\n\x12UpdateReview\x12Q.github.com.metaprov.modelaapi.services.review.v1.UpdateReviewRequest\x1aR.github.com.metaprov.modelaapi.services.review.v1.UpdateReviewResponse\"e\x82\xd3\xe4\x93\x02_\x1aZ/api/v1alpha1/reviews/{review.metadata.namespace}/{review.metadata.name}:\x01*\x12\xed\x01\n\x12\x44\x65leteReview\x12Q.github.com.metaprov.modelaapi.services.review.v1.DeleteReviewRequest\x1aR.github.com.metaprov.modelaapi.services.review.v1.DeleteReviewResponse\"0\x82\xd3\xe4\x93\x02**(/api/v1/reviews/{namespace}/{name}B8Z6github.com/metaprov/modelaapi/services/review/v1b\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_GETCONVERSATIONREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.review.v1.GetReviewRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.review.v1.GetReviewRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.review.v1.GetReviewRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=430,
  serialized_end=475,
)

_GETCONVERSATIONREQUEST = _descriptor.Descriptor(
  name='GetReviewRequest',
  full_name='github.com.metaprov.modelaapi.services.review.v1.GetReviewRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.review.v1.GetReviewRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.review.v1.GetReviewRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.review.v1.GetReviewRequest.labels', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GETCONVERSATIONREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=263,
  serialized_end=475,
)


_GETCONVERSATIONRESPONSE = _descriptor.Descriptor(
  name='GetReviewResponse',
  full_name='github.com.metaprov.modelaapi.services.review.v1.GetReviewResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.review.v1.GetReviewResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.review.v1.GetReviewResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=477,
  serialized_end=598,
)


_CREATECONVERSATIONREQUEST = _descriptor.Descriptor(
  name='CreateReviewRequest',
  full_name='github.com.metaprov.modelaapi.services.review.v1.CreateReviewRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.review.v1.CreateReviewRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=600,
  serialized_end=709,
)


_CREATECONVERSATIONRESPONSE = _descriptor.Descriptor(
  name='CreateReviewResponse',
  full_name='github.com.metaprov.modelaapi.services.review.v1.CreateReviewResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=711,
  serialized_end=739,
)


_UPDATECONVERSATIONREQUEST = _descriptor.Descriptor(
  name='UpdateReviewRequest',
  full_name='github.com.metaprov.modelaapi.services.review.v1.UpdateReviewRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.review.v1.UpdateReviewRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=741,
  serialized_end=850,
)


_UPDATECONVERSATIONRESPONSE = _descriptor.Descriptor(
  name='UpdateReviewResponse',
  full_name='github.com.metaprov.modelaapi.services.review.v1.UpdateReviewResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=852,
  serialized_end=880,
)


_DELETECONVERSATIONREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.review.v1.DeleteReviewRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.review.v1.DeleteReviewRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.review.v1.DeleteReviewRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=430,
  serialized_end=475,
)

_DELETECONVERSATIONREQUEST = _descriptor.Descriptor(
  name='DeleteReviewRequest',
  full_name='github.com.metaprov.modelaapi.services.review.v1.DeleteReviewRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.review.v1.DeleteReviewRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.review.v1.DeleteReviewRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.review.v1.DeleteReviewRequest.labels', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DELETECONVERSATIONREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=883,
  serialized_end=1101,
)


_DELETECONVERSATIONRESPONSE = _descriptor.Descriptor(
  name='DeleteReviewResponse',
  full_name='github.com.metaprov.modelaapi.services.review.v1.DeleteReviewResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1103,
  serialized_end=1131,
)


_LISTCONVERSATIONREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.review.v1.ListReviewRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.review.v1.ListReviewRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.review.v1.ListReviewRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=430,
  serialized_end=475,
)

_LISTCONVERSATIONREQUEST = _descriptor.Descriptor(
  name='ListReviewRequest',
  full_name='github.com.metaprov.modelaapi.services.review.v1.ListReviewRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.review.v1.ListReviewRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.review.v1.ListReviewRequest.labels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='github.com.metaprov.modelaapi.services.review.v1.ListReviewRequest.page_size', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='github.com.metaprov.modelaapi.services.review.v1.ListReviewRequest.page_token', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTCONVERSATIONREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1134,
  serialized_end=1373,
)


_LISTCONVERSATIONRESPONSE = _descriptor.Descriptor(
  name='ListReviewResponse',
  full_name='github.com.metaprov.modelaapi.services.review.v1.ListReviewResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.review.v1.ListReviewResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='github.com.metaprov.modelaapi.services.review.v1.ListReviewResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1376,
  serialized_end=1514,
)

_GETCONVERSATIONREQUEST_LABELSENTRY.containing_type = _GETCONVERSATIONREQUEST
_GETCONVERSATIONREQUEST.fields_by_name['labels'].message_type = _GETCONVERSATIONREQUEST_LABELSENTRY
_GETCONVERSATIONRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._CONVERSATION
_CREATECONVERSATIONREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._CONVERSATION
_UPDATECONVERSATIONREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._CONVERSATION
_DELETECONVERSATIONREQUEST_LABELSENTRY.containing_type = _DELETECONVERSATIONREQUEST
_DELETECONVERSATIONREQUEST.fields_by_name['labels'].message_type = _DELETECONVERSATIONREQUEST_LABELSENTRY
_LISTCONVERSATIONREQUEST_LABELSENTRY.containing_type = _LISTCONVERSATIONREQUEST
_LISTCONVERSATIONREQUEST.fields_by_name['labels'].message_type = _LISTCONVERSATIONREQUEST_LABELSENTRY
_LISTCONVERSATIONRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._CONVERSATIONLIST
DESCRIPTOR.message_types_by_name['GetReviewRequest'] = _GETCONVERSATIONREQUEST
DESCRIPTOR.message_types_by_name['GetReviewResponse'] = _GETCONVERSATIONRESPONSE
DESCRIPTOR.message_types_by_name['CreateReviewRequest'] = _CREATECONVERSATIONREQUEST
DESCRIPTOR.message_types_by_name['CreateReviewResponse'] = _CREATECONVERSATIONRESPONSE
DESCRIPTOR.message_types_by_name['UpdateReviewRequest'] = _UPDATECONVERSATIONREQUEST
DESCRIPTOR.message_types_by_name['UpdateReviewResponse'] = _UPDATECONVERSATIONRESPONSE
DESCRIPTOR.message_types_by_name['DeleteReviewRequest'] = _DELETECONVERSATIONREQUEST
DESCRIPTOR.message_types_by_name['DeleteReviewResponse'] = _DELETECONVERSATIONRESPONSE
DESCRIPTOR.message_types_by_name['ListReviewRequest'] = _LISTCONVERSATIONREQUEST
DESCRIPTOR.message_types_by_name['ListReviewResponse'] = _LISTCONVERSATIONRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetReviewRequest = _reflection.GeneratedProtocolMessageType('GetReviewRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETCONVERSATIONREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.GetReviewRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _GETCONVERSATIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.GetReviewRequest)
  })
_sym_db.RegisterMessage(GetReviewRequest)
_sym_db.RegisterMessage(GetReviewRequest.LabelsEntry)

GetReviewResponse = _reflection.GeneratedProtocolMessageType('GetReviewResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCONVERSATIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.GetReviewResponse)
  })
_sym_db.RegisterMessage(GetReviewResponse)

CreateReviewRequest = _reflection.GeneratedProtocolMessageType('CreateReviewRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECONVERSATIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.CreateReviewRequest)
  })
_sym_db.RegisterMessage(CreateReviewRequest)

CreateReviewResponse = _reflection.GeneratedProtocolMessageType('CreateReviewResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATECONVERSATIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.CreateReviewResponse)
  })
_sym_db.RegisterMessage(CreateReviewResponse)

UpdateReviewRequest = _reflection.GeneratedProtocolMessageType('UpdateReviewRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECONVERSATIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.UpdateReviewRequest)
  })
_sym_db.RegisterMessage(UpdateReviewRequest)

UpdateReviewResponse = _reflection.GeneratedProtocolMessageType('UpdateReviewResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECONVERSATIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.UpdateReviewResponse)
  })
_sym_db.RegisterMessage(UpdateReviewResponse)

DeleteReviewRequest = _reflection.GeneratedProtocolMessageType('DeleteReviewRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DELETECONVERSATIONREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.DeleteReviewRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _DELETECONVERSATIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.DeleteReviewRequest)
  })
_sym_db.RegisterMessage(DeleteReviewRequest)
_sym_db.RegisterMessage(DeleteReviewRequest.LabelsEntry)

DeleteReviewResponse = _reflection.GeneratedProtocolMessageType('DeleteReviewResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETECONVERSATIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.DeleteReviewResponse)
  })
_sym_db.RegisterMessage(DeleteReviewResponse)

ListReviewRequest = _reflection.GeneratedProtocolMessageType('ListReviewRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTCONVERSATIONREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.ListReviewRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTCONVERSATIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.ListReviewRequest)
  })
_sym_db.RegisterMessage(ListReviewRequest)
_sym_db.RegisterMessage(ListReviewRequest.LabelsEntry)

ListReviewResponse = _reflection.GeneratedProtocolMessageType('ListReviewResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCONVERSATIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.review.v1.review_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.review.v1.ListReviewResponse)
  })
_sym_db.RegisterMessage(ListReviewResponse)


DESCRIPTOR._options = None
_GETCONVERSATIONREQUEST_LABELSENTRY._options = None
_DELETECONVERSATIONREQUEST_LABELSENTRY._options = None
_LISTCONVERSATIONREQUEST_LABELSENTRY._options = None

_CONVERSATIONSERVICE = _descriptor.ServiceDescriptor(
  name='ReviewService',
  full_name='github.com.metaprov.modelaapi.services.review.v1.ReviewService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1517,
  serialized_end=2772,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListReviews',
    full_name='github.com.metaprov.modelaapi.services.review.v1.ReviewService.ListReviews',
    index=0,
    containing_service=None,
    input_type=_LISTCONVERSATIONREQUEST,
    output_type=_LISTCONVERSATIONRESPONSE,
    serialized_options=b'\202\323\344\223\002)\022\'/api/v1alpha1/reviews/{namespace}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateReview',
    full_name='github.com.metaprov.modelaapi.services.review.v1.ReviewService.CreateReview',
    index=1,
    containing_service=None,
    input_type=_CREATECONVERSATIONREQUEST,
    output_type=_CREATECONVERSATIONRESPONSE,
    serialized_options=b'\202\323\344\223\002 \"\033/api/v1alpha1/reviews:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetReview',
    full_name='github.com.metaprov.modelaapi.services.review.v1.ReviewService.GetReview',
    index=2,
    containing_service=None,
    input_type=_GETCONVERSATIONREQUEST,
    output_type=_GETCONVERSATIONRESPONSE,
    serialized_options=b'\202\323\344\223\0020\022./api/v1alpha1/reviews/{namespace}/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateReview',
    full_name='github.com.metaprov.modelaapi.services.review.v1.ReviewService.UpdateReview',
    index=3,
    containing_service=None,
    input_type=_UPDATECONVERSATIONREQUEST,
    output_type=_UPDATECONVERSATIONRESPONSE,
    serialized_options=b'\202\323\344\223\002_\032Z/api/v1alpha1/reviews/{review.metadata.namespace}/{review.metadata.name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteReview',
    full_name='github.com.metaprov.modelaapi.services.review.v1.ReviewService.DeleteReview',
    index=4,
    containing_service=None,
    input_type=_DELETECONVERSATIONREQUEST,
    output_type=_DELETECONVERSATIONRESPONSE,
    serialized_options=b'\202\323\344\223\002**(/api/v1/reviews/{namespace}/{name}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CONVERSATIONSERVICE)

DESCRIPTOR.services_by_name['ReviewService'] = _CONVERSATIONSERVICE

# @@protoc_insertion_point(module_scope)
